==> calamares_3.2.17.1.orig.tar.gz: calamares-3.2.17.1/src/modules/users/UsersViewStep.h <==
/* === This file is part of Calamares - <https://github.com/calamares> ===
 *
 *   Copyright 2014-2015, Teo Mrnjavac <teo@kde.org>
 *   Copyright 2017, Adriaan de Groot <groot@kde.org>
 *
 *   Calamares is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   Calamares is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef USERSPAGEPLUGIN_H
#define USERSPAGEPLUGIN_H

#include <QObject>

#include <utils/PluginFactory.h>
#include <viewpages/ViewStep.h>

#include <PluginDllMacro.h>

#include <QVariant>

class UsersPage;

class PLUGINDLLEXPORT UsersViewStep : public Calamares::ViewStep
{
    Q_OBJECT

public:
    explicit UsersViewStep( QObject* parent = nullptr );
    virtual ~UsersViewStep() override;

    QString prettyName() const override;

    QWidget* widget() override;

    bool isNextEnabled() const override;
    bool isBackEnabled() const override;

    bool isAtBeginning() const override;
    bool isAtEnd() const override;

    QList< Calamares::job_ptr > jobs() const override;

    void onActivate() override;
    void onLeave() override;

    void setConfigurationMap( const QVariantMap& configurationMap ) override;

private:
    UsersPage* m_widget;
    QList< Calamares::job_ptr > m_jobs;

    QStringList m_defaultGroups;
};

CALAMARES_PLUGIN_FACTORY_DECLARATION( UsersViewStepFactory )

#endif  // USERSPAGEPLUGIN_H

==> calamares_3.2.20.orig.tar.gz: calamares-3.2.20/src/modules/users/UsersViewStep.h <==
/* === This file is part of Calamares - <https://github.com/calamares> ===
 *
 *   Copyright 2014-2015, Teo Mrnjavac <teo@kde.org>
 *   Copyright 2017, Adriaan de Groot <groot@kde.org>
 *
 *   Calamares is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   Calamares is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef USERSPAGEPLUGIN_H
#define USERSPAGEPLUGIN_H

#include "SetHostNameJob.h"

#include "DllMacro.h"
#include "utils/PluginFactory.h"
#include "viewpages/ViewStep.h"

#include <QObject>
#include <QVariant>

class UsersPage;

class PLUGINDLLEXPORT UsersViewStep : public Calamares::ViewStep
{
    Q_OBJECT

public:
    explicit UsersViewStep( QObject* parent = nullptr );
    virtual ~UsersViewStep() override;

    QString prettyName() const override;

    QWidget* widget() override;

    bool isNextEnabled() const override;
    bool isBackEnabled() const override;

    bool isAtBeginning() const override;
    bool isAtEnd() const override;

    QList< Calamares::job_ptr > jobs() const override;

    void onActivate() override;
    void onLeave() override;

    void setConfigurationMap( const QVariantMap& configurationMap ) override;

private:
    UsersPage* m_widget;
    QList< Calamares::job_ptr > m_jobs;

    QStringList m_defaultGroups;
    SetHostNameJob::Actions m_actions;
};

CALAMARES_PLUGIN_FACTORY_DECLARATION( UsersViewStepFactory )

#endif  // USERSPAGEPLUGIN_H
